# Changelog

## Version v0.5.0 (development)

- Implemented an alternative cast method discriminating None values
- fix large cookie error after > 100 edits
- add support to store a list of entities

## Version v0.4.0

- fix datamodel-code-generator version to 0.15.0

## Version v0.4.0

- use editslots API
- remove None entries in json exports
- set default content for header and footer slot
- improve docs
- update examples

## Version v0.3.0

- add local slot edit feature


## Version v0.2.0

- rename OSL to OSW
- add page package feature


## Version v0.1.0

- create package
